Covasim

{{ app.title }} Documentation Paper About {{app.version}}

{{ app.title }} is an agent-based model that simulates the transmission of COVID-19 (novel coronavirus, SARS-CoV-2) in a population. Each individual in the model may pass through the following stages of COVID-19 infection: susceptible, exposed, infectious, and recovered (SEIR). The epidemiological parameter values are taken from literature.

Viral transmission occurs on a fixed contact network with undirected edges. Each day, infectious individuals expose susceptible individuals to possible infection. By default, the daily probability of infection, number of contacts, and mean duration of infectiousness roughly equates to R0 = 2.5 and a doubling time of 6-7 days. For more information, please read the paper or visit the GitHub repository.

Note: Models are only as good as the values of the parameters put into them. This is a rapidly changing situation, and we will update content as relevant information is received.

Acknowledgements: Covasim is currently under active development by IDM's COVID-19 Response Team. Model development is led by Daniel Klein, Cliff Kerr, Robyn Stuart, Romesh Abeysuriya, and Dina Mistry. UI design is led by Lauren George, William Chen, and Scott Ayers, inspired by a prototype from Brian Lovin. For the full list of contributors, please see our Contributors page.

Note: the Covasim webapp is currently in development and is intended for illustrative explorations of COVID-19 epidemic dynamics only. It is not intended to be used as a policy or decision-making tool. For more detailed information on COVID-19 modeling, please contact us at covasim@idmod.org.

General options
Choose simulation presets
Example parameter configurations
Reset parameters to default values
Download parameters
Upload parameters
Simulation duration (in days): {{paramError.sim_length}} {{sim_length.tip}}
Interventions
Model parameters
Population parameters
{{par.name}}: {{paramError[key]}}
Epidemiological parameters
{{par.name}}: {{paramError[key]}}
Animate Running... Run